oauthclient

package
v0.5.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the oauthclient type in the database.
	Label = "oauth_client"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldClientID holds the string denoting the client_id field in the database.
	FieldClientID = "client_id"
	// FieldClientSecretHash holds the string denoting the client_secret_hash field in the database.
	FieldClientSecretHash = "client_secret_hash"
	// FieldRedirectUris holds the string denoting the redirect_uris field in the database.
	FieldRedirectUris = "redirect_uris"
	// FieldGrantTypes holds the string denoting the grant_types field in the database.
	FieldGrantTypes = "grant_types"
	// FieldResponseTypes holds the string denoting the response_types field in the database.
	FieldResponseTypes = "response_types"
	// FieldScopes holds the string denoting the scopes field in the database.
	FieldScopes = "scopes"
	// FieldIsPublic holds the string denoting the is_public field in the database.
	FieldIsPublic = "is_public"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldWorkspaceID holds the string denoting the workspace_id field in the database.
	FieldWorkspaceID = "workspace_id"
	// Table holds the table name of the oauthclient in the database.
	Table = "oauth_clients"
)

Variables

var (
	// ClientIDValidator is a validator for the "client_id" field. It is called by the builders before save.
	ClientIDValidator func(string) error
	// DefaultClientSecretHash holds the default value on creation for the "client_secret_hash" field.
	DefaultClientSecretHash string
	// DefaultRedirectUris holds the default value on creation for the "redirect_uris" field.
	DefaultRedirectUris []string
	// DefaultGrantTypes holds the default value on creation for the "grant_types" field.
	DefaultGrantTypes []string
	// DefaultResponseTypes holds the default value on creation for the "response_types" field.
	DefaultResponseTypes []string
	// DefaultScopes holds the default value on creation for the "scopes" field.
	DefaultScopes string
	// ScopesValidator is a validator for the "scopes" field. It is called by the builders before save.
	ScopesValidator func(string) error
	// DefaultIsPublic holds the default value on creation for the "is_public" field.
	DefaultIsPublic bool
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
)

Columns holds all SQL columns for oauthclient fields.

Functions

func And

func And(predicates ...predicate.OAuthClient) predicate.OAuthClient

And groups predicates with the AND operator between them.

func ClientID

func ClientID(v string) predicate.OAuthClient

ClientID applies equality check predicate on the "client_id" field. It's identical to ClientIDEQ.

func ClientIDContains

func ClientIDContains(v string) predicate.OAuthClient

ClientIDContains applies the Contains predicate on the "client_id" field.

func ClientIDContainsFold

func ClientIDContainsFold(v string) predicate.OAuthClient

ClientIDContainsFold applies the ContainsFold predicate on the "client_id" field.

func ClientIDEQ

func ClientIDEQ(v string) predicate.OAuthClient

ClientIDEQ applies the EQ predicate on the "client_id" field.

func ClientIDEqualFold

func ClientIDEqualFold(v string) predicate.OAuthClient

ClientIDEqualFold applies the EqualFold predicate on the "client_id" field.

func ClientIDGT

func ClientIDGT(v string) predicate.OAuthClient

ClientIDGT applies the GT predicate on the "client_id" field.

func ClientIDGTE

func ClientIDGTE(v string) predicate.OAuthClient

ClientIDGTE applies the GTE predicate on the "client_id" field.

func ClientIDHasPrefix

func ClientIDHasPrefix(v string) predicate.OAuthClient

ClientIDHasPrefix applies the HasPrefix predicate on the "client_id" field.

func ClientIDHasSuffix

func ClientIDHasSuffix(v string) predicate.OAuthClient

ClientIDHasSuffix applies the HasSuffix predicate on the "client_id" field.

func ClientIDIn

func ClientIDIn(vs ...string) predicate.OAuthClient

ClientIDIn applies the In predicate on the "client_id" field.

func ClientIDLT

func ClientIDLT(v string) predicate.OAuthClient

ClientIDLT applies the LT predicate on the "client_id" field.

func ClientIDLTE

func ClientIDLTE(v string) predicate.OAuthClient

ClientIDLTE applies the LTE predicate on the "client_id" field.

func ClientIDNEQ

func ClientIDNEQ(v string) predicate.OAuthClient

ClientIDNEQ applies the NEQ predicate on the "client_id" field.

func ClientIDNotIn

func ClientIDNotIn(vs ...string) predicate.OAuthClient

ClientIDNotIn applies the NotIn predicate on the "client_id" field.

func ClientSecretHash

func ClientSecretHash(v string) predicate.OAuthClient

ClientSecretHash applies equality check predicate on the "client_secret_hash" field. It's identical to ClientSecretHashEQ.

func ClientSecretHashContains

func ClientSecretHashContains(v string) predicate.OAuthClient

ClientSecretHashContains applies the Contains predicate on the "client_secret_hash" field.

func ClientSecretHashContainsFold

func ClientSecretHashContainsFold(v string) predicate.OAuthClient

ClientSecretHashContainsFold applies the ContainsFold predicate on the "client_secret_hash" field.

func ClientSecretHashEQ

func ClientSecretHashEQ(v string) predicate.OAuthClient

ClientSecretHashEQ applies the EQ predicate on the "client_secret_hash" field.

func ClientSecretHashEqualFold

func ClientSecretHashEqualFold(v string) predicate.OAuthClient

ClientSecretHashEqualFold applies the EqualFold predicate on the "client_secret_hash" field.

func ClientSecretHashGT

func ClientSecretHashGT(v string) predicate.OAuthClient

ClientSecretHashGT applies the GT predicate on the "client_secret_hash" field.

func ClientSecretHashGTE

func ClientSecretHashGTE(v string) predicate.OAuthClient

ClientSecretHashGTE applies the GTE predicate on the "client_secret_hash" field.

func ClientSecretHashHasPrefix

func ClientSecretHashHasPrefix(v string) predicate.OAuthClient

ClientSecretHashHasPrefix applies the HasPrefix predicate on the "client_secret_hash" field.

func ClientSecretHashHasSuffix

func ClientSecretHashHasSuffix(v string) predicate.OAuthClient

ClientSecretHashHasSuffix applies the HasSuffix predicate on the "client_secret_hash" field.

func ClientSecretHashIn

func ClientSecretHashIn(vs ...string) predicate.OAuthClient

ClientSecretHashIn applies the In predicate on the "client_secret_hash" field.

func ClientSecretHashLT

func ClientSecretHashLT(v string) predicate.OAuthClient

ClientSecretHashLT applies the LT predicate on the "client_secret_hash" field.

func ClientSecretHashLTE

func ClientSecretHashLTE(v string) predicate.OAuthClient

ClientSecretHashLTE applies the LTE predicate on the "client_secret_hash" field.

func ClientSecretHashNEQ

func ClientSecretHashNEQ(v string) predicate.OAuthClient

ClientSecretHashNEQ applies the NEQ predicate on the "client_secret_hash" field.

func ClientSecretHashNotIn

func ClientSecretHashNotIn(vs ...string) predicate.OAuthClient

ClientSecretHashNotIn applies the NotIn predicate on the "client_secret_hash" field.

func ID

func ID(id int) predicate.OAuthClient

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.OAuthClient

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.OAuthClient

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.OAuthClient

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.OAuthClient

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.OAuthClient

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.OAuthClient

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.OAuthClient

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.OAuthClient

IDNotIn applies the NotIn predicate on the ID field.

func IsPublic

func IsPublic(v bool) predicate.OAuthClient

IsPublic applies equality check predicate on the "is_public" field. It's identical to IsPublicEQ.

func IsPublicEQ

func IsPublicEQ(v bool) predicate.OAuthClient

IsPublicEQ applies the EQ predicate on the "is_public" field.

func IsPublicNEQ

func IsPublicNEQ(v bool) predicate.OAuthClient

IsPublicNEQ applies the NEQ predicate on the "is_public" field.

func Name

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.OAuthClient

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.OAuthClient

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.OAuthClient

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.OAuthClient

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.OAuthClient

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.OAuthClient

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.OAuthClient

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.OAuthClient

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.OAuthClient

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.OAuthClient

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.OAuthClient

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.OAuthClient

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.OAuthClient

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.OAuthClient) predicate.OAuthClient

Or groups predicates with the OR operator between them.

func Scopes

func Scopes(v string) predicate.OAuthClient

Scopes applies equality check predicate on the "scopes" field. It's identical to ScopesEQ.

func ScopesContains

func ScopesContains(v string) predicate.OAuthClient

ScopesContains applies the Contains predicate on the "scopes" field.

func ScopesContainsFold

func ScopesContainsFold(v string) predicate.OAuthClient

ScopesContainsFold applies the ContainsFold predicate on the "scopes" field.

func ScopesEQ

func ScopesEQ(v string) predicate.OAuthClient

ScopesEQ applies the EQ predicate on the "scopes" field.

func ScopesEqualFold

func ScopesEqualFold(v string) predicate.OAuthClient

ScopesEqualFold applies the EqualFold predicate on the "scopes" field.

func ScopesGT

func ScopesGT(v string) predicate.OAuthClient

ScopesGT applies the GT predicate on the "scopes" field.

func ScopesGTE

func ScopesGTE(v string) predicate.OAuthClient

ScopesGTE applies the GTE predicate on the "scopes" field.

func ScopesHasPrefix

func ScopesHasPrefix(v string) predicate.OAuthClient

ScopesHasPrefix applies the HasPrefix predicate on the "scopes" field.

func ScopesHasSuffix

func ScopesHasSuffix(v string) predicate.OAuthClient

ScopesHasSuffix applies the HasSuffix predicate on the "scopes" field.

func ScopesIn

func ScopesIn(vs ...string) predicate.OAuthClient

ScopesIn applies the In predicate on the "scopes" field.

func ScopesLT

func ScopesLT(v string) predicate.OAuthClient

ScopesLT applies the LT predicate on the "scopes" field.

func ScopesLTE

func ScopesLTE(v string) predicate.OAuthClient

ScopesLTE applies the LTE predicate on the "scopes" field.

func ScopesNEQ

func ScopesNEQ(v string) predicate.OAuthClient

ScopesNEQ applies the NEQ predicate on the "scopes" field.

func ScopesNotIn

func ScopesNotIn(vs ...string) predicate.OAuthClient

ScopesNotIn applies the NotIn predicate on the "scopes" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func WorkspaceID

func WorkspaceID(v int) predicate.OAuthClient

WorkspaceID applies equality check predicate on the "workspace_id" field. It's identical to WorkspaceIDEQ.

func WorkspaceIDEQ

func WorkspaceIDEQ(v int) predicate.OAuthClient

WorkspaceIDEQ applies the EQ predicate on the "workspace_id" field.

func WorkspaceIDGT

func WorkspaceIDGT(v int) predicate.OAuthClient

WorkspaceIDGT applies the GT predicate on the "workspace_id" field.

func WorkspaceIDGTE

func WorkspaceIDGTE(v int) predicate.OAuthClient

WorkspaceIDGTE applies the GTE predicate on the "workspace_id" field.

func WorkspaceIDIn

func WorkspaceIDIn(vs ...int) predicate.OAuthClient

WorkspaceIDIn applies the In predicate on the "workspace_id" field.

func WorkspaceIDIsNil

func WorkspaceIDIsNil() predicate.OAuthClient

WorkspaceIDIsNil applies the IsNil predicate on the "workspace_id" field.

func WorkspaceIDLT

func WorkspaceIDLT(v int) predicate.OAuthClient

WorkspaceIDLT applies the LT predicate on the "workspace_id" field.

func WorkspaceIDLTE

func WorkspaceIDLTE(v int) predicate.OAuthClient

WorkspaceIDLTE applies the LTE predicate on the "workspace_id" field.

func WorkspaceIDNEQ

func WorkspaceIDNEQ(v int) predicate.OAuthClient

WorkspaceIDNEQ applies the NEQ predicate on the "workspace_id" field.

func WorkspaceIDNotIn

func WorkspaceIDNotIn(vs ...int) predicate.OAuthClient

WorkspaceIDNotIn applies the NotIn predicate on the "workspace_id" field.

func WorkspaceIDNotNil

func WorkspaceIDNotNil() predicate.OAuthClient

WorkspaceIDNotNil applies the NotNil predicate on the "workspace_id" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the OAuthClient queries.

func ByClientID

func ByClientID(opts ...sql.OrderTermOption) OrderOption

ByClientID orders the results by the client_id field.

func ByClientSecretHash

func ByClientSecretHash(opts ...sql.OrderTermOption) OrderOption

ByClientSecretHash orders the results by the client_secret_hash field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsPublic

func ByIsPublic(opts ...sql.OrderTermOption) OrderOption

ByIsPublic orders the results by the is_public field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByScopes

func ByScopes(opts ...sql.OrderTermOption) OrderOption

ByScopes orders the results by the scopes field.

func ByWorkspaceID

func ByWorkspaceID(opts ...sql.OrderTermOption) OrderOption

ByWorkspaceID orders the results by the workspace_id field.

Jump to